<div style="width:720px;">
    <div id="generic_key_{{ id }}" style=""></div>
    <input type="hidden" id="{{ id }}" name="{{ name }}" value="{{ value }}" />
</div>

{% if not is_templated %}
<script type="text/javascript">
(function($) {
  armstrong.widgets.generickey($, {
    content_type_name: "{{ content_type_name }}",
    object_id_name: "{{ object_id_name }}",
    facetURL: "{{ facet_url }}",
    queryLookupURL: "{{ query_lookup_url }}",
    baseLookupURL: "{{ base_lookup_url }}",
    id: "{{ id }}"
  });
})(django.jQuery)
</script>
{% endif %}
